%% This function reads the sensors
function [ SensorOris ] = read_sensors( sensorFile )
% READ_SENSORS Reads the calibrated sensor data
%    INPUT:
%       sensorFile: filename of the sensor data
%    OUTPUT:
%         Struct containing the sensor orientation data
%
% This function is part of the MPI08 data set, to be obtained at 
% http://www.tnt.uni-hannover.de/project/MPI08_Database/
%
% Written by: Gerard Pons
% Revision:   1.0
% Date:       10.10.2010
%
% Copyright 2010, MPI Informatik, Germany, and Hannover University, Germany.
% All Rights Reserved Permission to use, copy, modify, and distribute this
% software and its documentation for any non-commercial purpose is hereby
% granted without fee, provided that the above copyright notice appear in
% all copies and that both that copyright notice and this permission
% notice appear in supporting documentation, and that the name of the
% author not be used in advertising or publicity pertaining to distribution
% of the software without specific, written prior permission.
% THE AUTHOR DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE,
% INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR ANY
% PARTICULAR PURPOSE. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY
% SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER
% RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF
% CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
% CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.


fid=fopen(sensorFile,'r');
if (fid==-1)
    error(['Could not open the file ' sensorFile])
    return;
end
fscanf(fid,'%s',1);
NumFrames=fscanf(fid,'%d',1);
fscanf(fid,'%s',1);
NumSens=fscanf(fid,'%d',1);
fscanf(fid,'%c',2);
for s=1:NumSens
    SensorOris(s).BodyPart=fscanf(fid,'%s',1);
    SensorOris(s).JointID=fscanf(fid,'%d',1);
    SensorOris(s).JointID=SensorOris(s).JointID+1;
end
AllQuaternions = fscanf(fid,'%f',[4*NumSens,inf]);
BodyParts={'lknee_lankle' 'rknee_rankle' 'chest_neck' 'lwrist_lhand' 'rwrist_rhand'};
IDs=[15 20 22 6 11]; %C++ tracking code
IDs=IDs+1;           %Matlab numbering
for i=1:NumSens
    SensorOris(i).quaternions=AllQuaternions((4*(i-1)+1):4*i,:);
end
fclose(fid);
end